import React from 'react';
import { mount } from 'enzyme';
import renderer from 'react-test-renderer';
import CameraIcon from '../../svgs/icons/camera-icon.svg';
import Button from './index';
describe('<Button />', function () {
  describe('UI snapshots', function () {
    it('renders with props', function () {
      var tree = renderer.create(React.createElement(Button, {
        disabled: true,
        onClick: function onClick() {},
        icon: React.createElement(CameraIcon, null)
      }, "Button Text")).toJSON();
      expect(tree).toMatchSnapshot();
    });
  });
  describe('onClick callback', function () {
    it('should be invoked onClick', function () {
      var spy = jest.fn();
      var button = mount(React.createElement(Button, {
        onClick: spy
      }, "Button Text"));
      button.simulate('click');
      expect(spy).toHaveBeenCalled();
    });
    it('should not be invoked if disabled', function () {
      var spy = jest.fn();
      var button = mount(React.createElement(Button, {
        disabled: true,
        onClick: spy
      }, "Button Text"));
      button.simulate('click');
      expect(spy).not.toHaveBeenCalled();
    });
    it('should not be invoked if loading', function () {
      var spy = jest.fn();
      var button = mount(React.createElement(Button, {
        loading: true,
        onClick: spy
      }, "Button Text"));
      button.simulate('click');
      expect(spy).not.toHaveBeenCalled();
    });
  });
});