import styled from '@emotion/styled';
import { css } from '@emotion/core';
import round from 'lodash.round';
import { withDeprecationWarning } from '../../utils';
import { COLORS, TYPOGRAPHY_CONSTANTS } from '../../constants';
var displayStyle =
/*#__PURE__*/
css("color:", COLORS.primary, ";font-size:", TYPOGRAPHY_CONSTANTS.fontSize.display, ";font-weight:", TYPOGRAPHY_CONSTANTS.fontWeight.bold, ";line-height:", round(48 / 36, 2), ";");
var headingStyle =
/*#__PURE__*/
css("color:", COLORS.primary, ";font-size:", TYPOGRAPHY_CONSTANTS.fontSize.heading, ";font-weight:", TYPOGRAPHY_CONSTANTS.fontWeight.bold, ";line-height:", round(40 / 24, 2), ";");
var titleStyle =
/*#__PURE__*/
css("color:", COLORS.primary, ";font-size:", TYPOGRAPHY_CONSTANTS.fontSize.title, ";line-height:", round(32 / 20, 2), ";font-weight:", TYPOGRAPHY_CONSTANTS.fontWeight.bold, ";");
export var baseBodyStyles = "\n  color: ".concat(COLORS.purpleTint1, ";\n  font-size: ").concat(TYPOGRAPHY_CONSTANTS.fontSize.body, ";\n  line-height: ").concat(round(28 / 16, 2), ";\n");
var bodyStyle =
/*#__PURE__*/
css(baseBodyStyles);
var captionStyle =
/*#__PURE__*/
css("color:", COLORS.purpleTint2, ";font-size:", TYPOGRAPHY_CONSTANTS.fontSize.caption, ";line-height:", round(24 / 14, 2), ";");
var errorStyle =
/*#__PURE__*/
css(captionStyle, ";color:", COLORS.accent, ";");
var successStyle =
/*#__PURE__*/
css(captionStyle, ";color:", COLORS.success, ";");
var labelStyle =
/*#__PURE__*/
css("color:", COLORS.purpleTint1, ";font-size:", TYPOGRAPHY_CONSTANTS.fontSize.label, ";line-height:", round(20 / 12, 2), ";");
var buttonStyle =
/*#__PURE__*/
css(labelStyle, ";font-weight:", TYPOGRAPHY_CONSTANTS.fontWeight.bold, ";letter-spacing:1px;text-transform:uppercase;");
var linkStyle =
/*#__PURE__*/
css("border-bottom:1px solid currentColor;cursor:pointer;text-decoration:none;color:inherit;opacity:1;transition:opacity 350ms;&:hover{opacity:0.6;transition:opacity 350ms;}");
export var style = {
  display: displayStyle,
  heading: headingStyle,
  title: titleStyle,
  body: bodyStyle,
  caption: captionStyle,
  error: errorStyle,
  success: successStyle,
  label: labelStyle,
  button: buttonStyle,
  link: linkStyle
};
var Button =
/*#__PURE__*/
styled("span", {
  target: "eeatqou0"
})(buttonStyle);
var Caption =
/*#__PURE__*/
styled("p", {
  target: "eeatqou1"
})(captionStyle);
var Display =
/*#__PURE__*/
styled("h1", {
  target: "eeatqou2"
})(displayStyle);
var ErrorComponent =
/*#__PURE__*/
styled("p", {
  target: "eeatqou3"
})(errorStyle);
var Heading =
/*#__PURE__*/
styled("h2", {
  target: "eeatqou4"
})(headingStyle);
var Label =
/*#__PURE__*/
styled("label", {
  target: "eeatqou5"
})(labelStyle);
var Link =
/*#__PURE__*/
styled("a", {
  target: "eeatqou6"
})(linkStyle);
var Success =
/*#__PURE__*/
styled("p", {
  target: "eeatqou7"
})(successStyle);
var Title =
/*#__PURE__*/
styled("h3", {
  target: "eeatqou8"
})(titleStyle);
var Typography = {
  Button: Button,
  Caption: Caption,
  Display: Display,
  Error: ErrorComponent,
  Heading: Heading,
  Label: Label,
  Link: Link,
  Success: Success,
  Title: Title,
  // Legacy names. Will be removed in v2 (next major)
  LinkTag: Link,
  ButtonText: Button,
  SuccessText: Success,
  ErrorText: ErrorComponent
};
var deprecatedProperties = {
  LinkTag: 'LinkTag will be deprecated in v2. Use Link instead',
  ButtonText: 'ButtonText will be deprecated in v2. Use Button instead',
  SuccessText: 'SuccessText will be deprecated in v2. Use Success instead',
  ErrorText: 'ErrorText will be deprecated in v2. Use Error instead'
};
export default withDeprecationWarning(Typography, deprecatedProperties);